#vider tout
rm(list=ls())

#charger les packages
library(xlsx) #lecture directe des fichiers EXCEL

#Q.0 charger les donnes
donnees <- read.xlsx(file="infidelites.xlsx",header=T,sheetIndex=1)

#description
str(donnees)

#summary
summary(donnees)

#nombre d'observations
print(nrow(donnees))

#nombre de variables 
print(ncol(donnees))

#Q.1.a - Recoder la variable cible Y
Z <- factor(ifelse(donnees$Y == 0, 0, 1))
print(table(Z))

#Q.1.b - Nouvelle base
infidelite <- cbind(Z,donnees[,2:9])
str(infidelite)

#Q.2 Diffrecienciation homme/femme
#Sex n'est pas siginificatif  5%, pas de diffrenciation
print(summary(glm(Z ~ Sex, data = infidelite, family = binomial)))

#Q.3 - regression logistique
#variables significatives  5% au sens de Wald :
#age, years married, religious, rating marriage
#signe du coefficient positif : plus de risque d'tre infidle
#signe ngatif : l'inverse
modele <- summary(glm(Z ~ ., data = infidelite, family = binomial))
print(modele)

#Q.4 - Tester le retrait de Sex, Children, Education, Occupation
modele.2 <- summary(glm(Z ~ Age + YearsMarried+Religious+RatingMarriage, data = infidelite, family = binomial))
print(modele.2)

#Q.4.a - comparaison des AIC > le second modle prsente un AIC plus faible
#-> le retrait des variables est justifi
print(modele$aic - modele.2$aic)

#Q.4.b - test du rapport de vraisemblance
# 5%, les 4 variables prises en bloc ne sont pas significatives
#leur retrait est justifi
LR <- modele.2$deviance - modele$deviance
print(LR)
print(pchisq(LR,4,lower.tail=F))

#Q.5 corrlation
print(cor(infidelite$Age,infidelite$YearsMarried))

#Q.6.a
print(summary(glm(Z ~ Age, data = infidelite, family = binomial)))

#Q.6.b
print(summary(glm(Z ~ YearsMarried, data = infidelite, family = binomial)))

#Q.6.c
print(summary(glm(Z ~ Age + YearsMarried, data = infidelite, family = binomial)))

#Q.6.d - graphique Age vs. YearsMarried, illustr par Z
plot(jitter(infidelite$Age,a=0.65),jitter(infidelite$YearsMarried,a=0.65),col=c("green","red")[infidelite$Z])

#*******************
#analyse  3 classes
#*******************

#Q.7.a
G <- donnees$Y
G[donnees$Y==0] <- 1
G[donnees$Y>=1 & donnees$Y<=3] <- 2
G[donnees$Y>3] <- 3
G <- factor(G)
levels(G) <- c("jamais","un_peu","beaucoup")
#distribution
print(table(G))

#Q.7.b - avec un arbre de dcision
infidelite.ter <- cbind(G,donnees[,2:9])
library(rpart)
arbre <- rpart(G ~ ., data = infidelite.ter,control=rpart.control(minsplit=5,minbucket=2))
print(arbre)

#affichage graphique
library(rpart.plot)
rpart.plot(arbre)

#Q.7.b - avec une analyse discriminante
library(MASS)
adl <- lda(G ~ ., data = infidelite.ter)
print(adl)

projection <- predict(adl)
plot(projection$x[,1],projection$x[,2],col=c("green","blue","red")[unclass(G)])
